aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/utils/SkTextureCompressor.h
diff options
context:
space:
mode:
authorGravatar reed <reed@google.com>2015-06-08 10:47:12 -0700
committerGravatar Commit bot <commit-bot@chromium.org>2015-06-08 10:47:13 -0700
commitc31af44336f5eb4a50e83e76e51962d46c3ed458 (patch)
tree244dcbfbeb638de8da65980dd59707ee323c5d24 /src/utils/SkTextureCompressor.h
parent77dcbdeb19d26e52428e392fca0ec9a72658b746 (diff)
change SkDraw and all Blitters to use pixmap instead of bitmap
Diffstat (limited to 'src/utils/SkTextureCompressor.h')
-rw-r--r--src/utils/SkTextureCompressor.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/utils/SkTextureCompressor.h b/src/utils/SkTextureCompressor.h
index e35bc957ac..e31a5ab48d 100644
--- a/src/utils/SkTextureCompressor.h
+++ b/src/utils/SkTextureCompressor.h
@@ -55,10 +55,10 @@ namespace SkTextureCompressor {
int GetCompressedDataSize(Format fmt, int width, int height);
// Returns an SkData holding a blob of compressed data that corresponds
// to the bitmap. If the bitmap colorType cannot be compressed using the
// associated format, then we return NULL. The caller is responsible for
// calling unref() on the returned data.
- SkData* CompressBitmapToFormat(const SkBitmap& bitmap, Format format);
+ SkData* CompressBitmapToFormat(const SkPixmap&, Format format);
// Compresses the given src data into dst. The src data is assumed to be
// large enough to hold width*height pixels. The dst data is expected to
@@ -55,10 +55,10 @@ namespace SkTextureCompressor {
int GetCompressedDataSize(Format fmt, int width, int height);
// Returns an SkData holding a blob of compressed data that corresponds
- // to the bitmap. If the bitmap colorType cannot be compressed using the
+ // to the pixmap. If the pixmap colorType cannot be compressed using the
// associated format, then we return NULL. The caller is responsible for
// calling unref() on the returned data.